"""
Type annotations for medical-imaging service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_medical_imaging.type_defs import BlobTypeDef

    data: BlobTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping, Sequence
from datetime import datetime
from typing import IO, Any, Union

from botocore.response import StreamingBody

from .literals import (
    DatastoreStatusType,
    ImageSetStateType,
    ImageSetWorkflowStatusType,
    JobStatusType,
    LosslessStorageFormatType,
    OperatorType,
    SortFieldType,
    SortOrderType,
    StorageTierType,
)

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict

__all__ = (
    "BlobTypeDef",
    "CopyDestinationImageSetPropertiesTypeDef",
    "CopyDestinationImageSetTypeDef",
    "CopyImageSetInformationTypeDef",
    "CopyImageSetRequestTypeDef",
    "CopyImageSetResponseTypeDef",
    "CopySourceImageSetInformationTypeDef",
    "CopySourceImageSetPropertiesTypeDef",
    "CreateDatastoreRequestTypeDef",
    "CreateDatastoreResponseTypeDef",
    "DICOMImportJobPropertiesTypeDef",
    "DICOMImportJobSummaryTypeDef",
    "DICOMStudyDateAndTimeTypeDef",
    "DICOMTagsTypeDef",
    "DICOMUpdatesTypeDef",
    "DatastorePropertiesTypeDef",
    "DatastoreSummaryTypeDef",
    "DeleteDatastoreRequestTypeDef",
    "DeleteDatastoreResponseTypeDef",
    "DeleteImageSetRequestTypeDef",
    "DeleteImageSetResponseTypeDef",
    "GetDICOMImportJobRequestTypeDef",
    "GetDICOMImportJobResponseTypeDef",
    "GetDatastoreRequestTypeDef",
    "GetDatastoreResponseTypeDef",
    "GetImageFrameRequestTypeDef",
    "GetImageFrameResponseTypeDef",
    "GetImageSetMetadataRequestTypeDef",
    "GetImageSetMetadataResponseTypeDef",
    "GetImageSetRequestTypeDef",
    "GetImageSetResponseTypeDef",
    "ImageFrameInformationTypeDef",
    "ImageSetPropertiesTypeDef",
    "ImageSetsMetadataSummaryTypeDef",
    "ListDICOMImportJobsRequestPaginateTypeDef",
    "ListDICOMImportJobsRequestTypeDef",
    "ListDICOMImportJobsResponseTypeDef",
    "ListDatastoresRequestPaginateTypeDef",
    "ListDatastoresRequestTypeDef",
    "ListDatastoresResponseTypeDef",
    "ListImageSetVersionsRequestPaginateTypeDef",
    "ListImageSetVersionsRequestTypeDef",
    "ListImageSetVersionsResponseTypeDef",
    "ListTagsForResourceRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "MetadataCopiesTypeDef",
    "MetadataUpdatesTypeDef",
    "OverridesTypeDef",
    "PaginatorConfigTypeDef",
    "ResponseMetadataTypeDef",
    "SearchByAttributeValueTypeDef",
    "SearchCriteriaTypeDef",
    "SearchFilterTypeDef",
    "SearchImageSetsRequestPaginateTypeDef",
    "SearchImageSetsRequestTypeDef",
    "SearchImageSetsResponseTypeDef",
    "SortTypeDef",
    "StartDICOMImportJobRequestTypeDef",
    "StartDICOMImportJobResponseTypeDef",
    "TagResourceRequestTypeDef",
    "TimestampTypeDef",
    "UntagResourceRequestTypeDef",
    "UpdateImageSetMetadataRequestTypeDef",
    "UpdateImageSetMetadataResponseTypeDef",
)

BlobTypeDef = Union[str, bytes, IO[Any], StreamingBody]

class CopyDestinationImageSetPropertiesTypeDef(TypedDict):
    imageSetId: str
    latestVersionId: str
    imageSetState: NotRequired[ImageSetStateType]
    imageSetWorkflowStatus: NotRequired[ImageSetWorkflowStatusType]
    createdAt: NotRequired[datetime]
    updatedAt: NotRequired[datetime]
    imageSetArn: NotRequired[str]

class CopyDestinationImageSetTypeDef(TypedDict):
    imageSetId: str
    latestVersionId: str

class CopySourceImageSetPropertiesTypeDef(TypedDict):
    imageSetId: str
    latestVersionId: str
    imageSetState: NotRequired[ImageSetStateType]
    imageSetWorkflowStatus: NotRequired[ImageSetWorkflowStatusType]
    createdAt: NotRequired[datetime]
    updatedAt: NotRequired[datetime]
    imageSetArn: NotRequired[str]

class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]

class MetadataCopiesTypeDef(TypedDict):
    copiableAttributes: str

class CreateDatastoreRequestTypeDef(TypedDict):
    clientToken: str
    datastoreName: NotRequired[str]
    tags: NotRequired[Mapping[str, str]]
    kmsKeyArn: NotRequired[str]
    lambdaAuthorizerArn: NotRequired[str]
    losslessStorageFormat: NotRequired[LosslessStorageFormatType]

class DICOMImportJobPropertiesTypeDef(TypedDict):
    jobId: str
    jobName: str
    jobStatus: JobStatusType
    datastoreId: str
    dataAccessRoleArn: str
    inputS3Uri: str
    outputS3Uri: str
    endedAt: NotRequired[datetime]
    submittedAt: NotRequired[datetime]
    message: NotRequired[str]

class DICOMImportJobSummaryTypeDef(TypedDict):
    jobId: str
    jobName: str
    jobStatus: JobStatusType
    datastoreId: str
    dataAccessRoleArn: NotRequired[str]
    endedAt: NotRequired[datetime]
    submittedAt: NotRequired[datetime]
    message: NotRequired[str]

class DICOMStudyDateAndTimeTypeDef(TypedDict):
    DICOMStudyDate: str
    DICOMStudyTime: NotRequired[str]

class DICOMTagsTypeDef(TypedDict):
    DICOMPatientId: NotRequired[str]
    DICOMPatientName: NotRequired[str]
    DICOMPatientBirthDate: NotRequired[str]
    DICOMPatientSex: NotRequired[str]
    DICOMStudyInstanceUID: NotRequired[str]
    DICOMStudyId: NotRequired[str]
    DICOMStudyDescription: NotRequired[str]
    DICOMNumberOfStudyRelatedSeries: NotRequired[int]
    DICOMNumberOfStudyRelatedInstances: NotRequired[int]
    DICOMAccessionNumber: NotRequired[str]
    DICOMSeriesInstanceUID: NotRequired[str]
    DICOMSeriesModality: NotRequired[str]
    DICOMSeriesBodyPart: NotRequired[str]
    DICOMSeriesNumber: NotRequired[int]
    DICOMStudyDate: NotRequired[str]
    DICOMStudyTime: NotRequired[str]

class DatastorePropertiesTypeDef(TypedDict):
    datastoreId: str
    datastoreName: str
    datastoreStatus: DatastoreStatusType
    kmsKeyArn: NotRequired[str]
    lambdaAuthorizerArn: NotRequired[str]
    losslessStorageFormat: NotRequired[LosslessStorageFormatType]
    datastoreArn: NotRequired[str]
    createdAt: NotRequired[datetime]
    updatedAt: NotRequired[datetime]

class DatastoreSummaryTypeDef(TypedDict):
    datastoreId: str
    datastoreName: str
    datastoreStatus: DatastoreStatusType
    datastoreArn: NotRequired[str]
    createdAt: NotRequired[datetime]
    updatedAt: NotRequired[datetime]

class DeleteDatastoreRequestTypeDef(TypedDict):
    datastoreId: str

class DeleteImageSetRequestTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str

class GetDICOMImportJobRequestTypeDef(TypedDict):
    datastoreId: str
    jobId: str

class GetDatastoreRequestTypeDef(TypedDict):
    datastoreId: str

class ImageFrameInformationTypeDef(TypedDict):
    imageFrameId: str

class GetImageSetMetadataRequestTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    versionId: NotRequired[str]

class GetImageSetRequestTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    versionId: NotRequired[str]

class OverridesTypeDef(TypedDict):
    forced: NotRequired[bool]

class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]

class ListDICOMImportJobsRequestTypeDef(TypedDict):
    datastoreId: str
    jobStatus: NotRequired[JobStatusType]
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListDatastoresRequestTypeDef(TypedDict):
    datastoreStatus: NotRequired[DatastoreStatusType]
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListImageSetVersionsRequestTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListTagsForResourceRequestTypeDef(TypedDict):
    resourceArn: str

TimestampTypeDef = Union[datetime, str]

class SortTypeDef(TypedDict):
    sortOrder: SortOrderType
    sortField: SortFieldType

class StartDICOMImportJobRequestTypeDef(TypedDict):
    dataAccessRoleArn: str
    clientToken: str
    datastoreId: str
    inputS3Uri: str
    outputS3Uri: str
    jobName: NotRequired[str]
    inputOwnerAccountId: NotRequired[str]

class TagResourceRequestTypeDef(TypedDict):
    resourceArn: str
    tags: Mapping[str, str]

class UntagResourceRequestTypeDef(TypedDict):
    resourceArn: str
    tagKeys: Sequence[str]

class DICOMUpdatesTypeDef(TypedDict):
    removableAttributes: NotRequired[BlobTypeDef]
    updatableAttributes: NotRequired[BlobTypeDef]

class CopyImageSetResponseTypeDef(TypedDict):
    datastoreId: str
    sourceImageSetProperties: CopySourceImageSetPropertiesTypeDef
    destinationImageSetProperties: CopyDestinationImageSetPropertiesTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class CreateDatastoreResponseTypeDef(TypedDict):
    datastoreId: str
    datastoreStatus: DatastoreStatusType
    ResponseMetadata: ResponseMetadataTypeDef

class DeleteDatastoreResponseTypeDef(TypedDict):
    datastoreId: str
    datastoreStatus: DatastoreStatusType
    ResponseMetadata: ResponseMetadataTypeDef

class DeleteImageSetResponseTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    imageSetState: ImageSetStateType
    imageSetWorkflowStatus: ImageSetWorkflowStatusType
    ResponseMetadata: ResponseMetadataTypeDef

class GetImageFrameResponseTypeDef(TypedDict):
    imageFrameBlob: StreamingBody
    contentType: str
    ResponseMetadata: ResponseMetadataTypeDef

class GetImageSetMetadataResponseTypeDef(TypedDict):
    imageSetMetadataBlob: StreamingBody
    contentType: str
    contentEncoding: str
    ResponseMetadata: ResponseMetadataTypeDef

class ListTagsForResourceResponseTypeDef(TypedDict):
    tags: dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef

class StartDICOMImportJobResponseTypeDef(TypedDict):
    datastoreId: str
    jobId: str
    jobStatus: JobStatusType
    submittedAt: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateImageSetMetadataResponseTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    latestVersionId: str
    imageSetState: ImageSetStateType
    imageSetWorkflowStatus: ImageSetWorkflowStatusType
    createdAt: datetime
    updatedAt: datetime
    message: str
    ResponseMetadata: ResponseMetadataTypeDef

class CopySourceImageSetInformationTypeDef(TypedDict):
    latestVersionId: str
    DICOMCopies: NotRequired[MetadataCopiesTypeDef]

class GetDICOMImportJobResponseTypeDef(TypedDict):
    jobProperties: DICOMImportJobPropertiesTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class ListDICOMImportJobsResponseTypeDef(TypedDict):
    jobSummaries: list[DICOMImportJobSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ImageSetsMetadataSummaryTypeDef(TypedDict):
    imageSetId: str
    version: NotRequired[int]
    createdAt: NotRequired[datetime]
    updatedAt: NotRequired[datetime]
    lastAccessedAt: NotRequired[datetime]
    storageTier: NotRequired[StorageTierType]
    DICOMTags: NotRequired[DICOMTagsTypeDef]
    isPrimary: NotRequired[bool]

class GetDatastoreResponseTypeDef(TypedDict):
    datastoreProperties: DatastorePropertiesTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class ListDatastoresResponseTypeDef(TypedDict):
    datastoreSummaries: list[DatastoreSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class GetImageFrameRequestTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    imageFrameInformation: ImageFrameInformationTypeDef

class GetImageSetResponseTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    versionId: str
    imageSetState: ImageSetStateType
    imageSetWorkflowStatus: ImageSetWorkflowStatusType
    createdAt: datetime
    updatedAt: datetime
    deletedAt: datetime
    message: str
    imageSetArn: str
    overrides: OverridesTypeDef
    isPrimary: bool
    lastAccessedAt: datetime
    storageTier: StorageTierType
    ResponseMetadata: ResponseMetadataTypeDef

class ImageSetPropertiesTypeDef(TypedDict):
    imageSetId: str
    versionId: str
    imageSetState: ImageSetStateType
    ImageSetWorkflowStatus: NotRequired[ImageSetWorkflowStatusType]
    createdAt: NotRequired[datetime]
    updatedAt: NotRequired[datetime]
    deletedAt: NotRequired[datetime]
    message: NotRequired[str]
    overrides: NotRequired[OverridesTypeDef]
    isPrimary: NotRequired[bool]

class ListDICOMImportJobsRequestPaginateTypeDef(TypedDict):
    datastoreId: str
    jobStatus: NotRequired[JobStatusType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListDatastoresRequestPaginateTypeDef(TypedDict):
    datastoreStatus: NotRequired[DatastoreStatusType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListImageSetVersionsRequestPaginateTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class SearchByAttributeValueTypeDef(TypedDict):
    DICOMPatientId: NotRequired[str]
    DICOMAccessionNumber: NotRequired[str]
    DICOMStudyId: NotRequired[str]
    DICOMStudyInstanceUID: NotRequired[str]
    DICOMSeriesInstanceUID: NotRequired[str]
    createdAt: NotRequired[TimestampTypeDef]
    updatedAt: NotRequired[TimestampTypeDef]
    DICOMStudyDateAndTime: NotRequired[DICOMStudyDateAndTimeTypeDef]
    isPrimary: NotRequired[bool]

class MetadataUpdatesTypeDef(TypedDict):
    DICOMUpdates: NotRequired[DICOMUpdatesTypeDef]
    revertToVersionId: NotRequired[str]

class CopyImageSetInformationTypeDef(TypedDict):
    sourceImageSet: CopySourceImageSetInformationTypeDef
    destinationImageSet: NotRequired[CopyDestinationImageSetTypeDef]

class SearchImageSetsResponseTypeDef(TypedDict):
    imageSetsMetadataSummaries: list[ImageSetsMetadataSummaryTypeDef]
    sort: SortTypeDef
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListImageSetVersionsResponseTypeDef(TypedDict):
    imageSetPropertiesList: list[ImageSetPropertiesTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

SearchFilterTypeDef = TypedDict(
    "SearchFilterTypeDef",
    {
        "values": Sequence[SearchByAttributeValueTypeDef],
        "operator": OperatorType,
    },
)

class UpdateImageSetMetadataRequestTypeDef(TypedDict):
    datastoreId: str
    imageSetId: str
    latestVersionId: str
    updateImageSetMetadataUpdates: MetadataUpdatesTypeDef
    force: NotRequired[bool]

class CopyImageSetRequestTypeDef(TypedDict):
    datastoreId: str
    sourceImageSetId: str
    copyImageSetInformation: CopyImageSetInformationTypeDef
    force: NotRequired[bool]
    promoteToPrimary: NotRequired[bool]

class SearchCriteriaTypeDef(TypedDict):
    filters: NotRequired[Sequence[SearchFilterTypeDef]]
    sort: NotRequired[SortTypeDef]

class SearchImageSetsRequestPaginateTypeDef(TypedDict):
    datastoreId: str
    searchCriteria: NotRequired[SearchCriteriaTypeDef]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class SearchImageSetsRequestTypeDef(TypedDict):
    datastoreId: str
    searchCriteria: NotRequired[SearchCriteriaTypeDef]
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]



"""
Type annotations for medical-imaging service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_medical_imaging.client import HealthImagingClient

    session = Session()
    client: HealthImagingClient = session.client("medical-imaging")
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    ListDatastoresPaginator,
    ListDICOMImportJobsPaginator,
    ListImageSetVersionsPaginator,
    SearchImageSetsPaginator,
)
from .type_defs import (
    CopyImageSetRequestTypeDef,
    CopyImageSetResponseTypeDef,
    CreateDatastoreRequestTypeDef,
    CreateDatastoreResponseTypeDef,
    DeleteDatastoreRequestTypeDef,
    DeleteDatastoreResponseTypeDef,
    DeleteImageSetRequestTypeDef,
    DeleteImageSetResponseTypeDef,
    GetDatastoreRequestTypeDef,
    GetDatastoreResponseTypeDef,
    GetDICOMImportJobRequestTypeDef,
    GetDICOMImportJobResponseTypeDef,
    GetImageFrameRequestTypeDef,
    GetImageFrameResponseTypeDef,
    GetImageSetMetadataRequestTypeDef,
    GetImageSetMetadataResponseTypeDef,
    GetImageSetRequestTypeDef,
    GetImageSetResponseTypeDef,
    ListDatastoresRequestTypeDef,
    ListDatastoresResponseTypeDef,
    ListDICOMImportJobsRequestTypeDef,
    ListDICOMImportJobsResponseTypeDef,
    ListImageSetVersionsRequestTypeDef,
    ListImageSetVersionsResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    SearchImageSetsRequestTypeDef,
    SearchImageSetsResponseTypeDef,
    StartDICOMImportJobRequestTypeDef,
    StartDICOMImportJobResponseTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateImageSetMetadataRequestTypeDef,
    UpdateImageSetMetadataResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack


__all__ = ("HealthImagingClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: type[BotocoreClientError]
    ClientError: type[BotocoreClientError]
    ConflictException: type[BotocoreClientError]
    InternalServerException: type[BotocoreClientError]
    ResourceNotFoundException: type[BotocoreClientError]
    ServiceQuotaExceededException: type[BotocoreClientError]
    ThrottlingException: type[BotocoreClientError]
    ValidationException: type[BotocoreClientError]


class HealthImagingClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging.html#HealthImaging.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        HealthImagingClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging.html#HealthImaging.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#generate_presigned_url)
        """

    def copy_image_set(
        self, **kwargs: Unpack[CopyImageSetRequestTypeDef]
    ) -> CopyImageSetResponseTypeDef:
        """
        Copy an image set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/copy_image_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#copy_image_set)
        """

    def create_datastore(
        self, **kwargs: Unpack[CreateDatastoreRequestTypeDef]
    ) -> CreateDatastoreResponseTypeDef:
        """
        Create a data store.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/create_datastore.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#create_datastore)
        """

    def delete_datastore(
        self, **kwargs: Unpack[DeleteDatastoreRequestTypeDef]
    ) -> DeleteDatastoreResponseTypeDef:
        """
        Delete a data store.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/delete_datastore.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#delete_datastore)
        """

    def delete_image_set(
        self, **kwargs: Unpack[DeleteImageSetRequestTypeDef]
    ) -> DeleteImageSetResponseTypeDef:
        """
        Delete an image set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/delete_image_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#delete_image_set)
        """

    def get_dicom_import_job(
        self, **kwargs: Unpack[GetDICOMImportJobRequestTypeDef]
    ) -> GetDICOMImportJobResponseTypeDef:
        """
        Get the import job properties to learn more about the job or job progress.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_dicom_import_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_dicom_import_job)
        """

    def get_datastore(
        self, **kwargs: Unpack[GetDatastoreRequestTypeDef]
    ) -> GetDatastoreResponseTypeDef:
        """
        Get data store properties.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_datastore.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_datastore)
        """

    def get_image_frame(
        self, **kwargs: Unpack[GetImageFrameRequestTypeDef]
    ) -> GetImageFrameResponseTypeDef:
        """
        Get an image frame (pixel data) for an image set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_image_frame.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_image_frame)
        """

    def get_image_set(
        self, **kwargs: Unpack[GetImageSetRequestTypeDef]
    ) -> GetImageSetResponseTypeDef:
        """
        Get image set properties.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_image_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_image_set)
        """

    def get_image_set_metadata(
        self, **kwargs: Unpack[GetImageSetMetadataRequestTypeDef]
    ) -> GetImageSetMetadataResponseTypeDef:
        """
        Get metadata attributes for an image set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_image_set_metadata.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_image_set_metadata)
        """

    def list_dicom_import_jobs(
        self, **kwargs: Unpack[ListDICOMImportJobsRequestTypeDef]
    ) -> ListDICOMImportJobsResponseTypeDef:
        """
        List import jobs created for a specific data store.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/list_dicom_import_jobs.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#list_dicom_import_jobs)
        """

    def list_datastores(
        self, **kwargs: Unpack[ListDatastoresRequestTypeDef]
    ) -> ListDatastoresResponseTypeDef:
        """
        List data stores.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/list_datastores.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#list_datastores)
        """

    def list_image_set_versions(
        self, **kwargs: Unpack[ListImageSetVersionsRequestTypeDef]
    ) -> ListImageSetVersionsResponseTypeDef:
        """
        List image set versions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/list_image_set_versions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#list_image_set_versions)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        Lists all tags associated with a medical imaging resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/list_tags_for_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#list_tags_for_resource)
        """

    def search_image_sets(
        self, **kwargs: Unpack[SearchImageSetsRequestTypeDef]
    ) -> SearchImageSetsResponseTypeDef:
        """
        Search image sets based on defined input attributes.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/search_image_sets.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#search_image_sets)
        """

    def start_dicom_import_job(
        self, **kwargs: Unpack[StartDICOMImportJobRequestTypeDef]
    ) -> StartDICOMImportJobResponseTypeDef:
        """
        Start importing bulk data into an <code>ACTIVE</code> data store.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/start_dicom_import_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#start_dicom_import_job)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> dict[str, Any]:
        """
        Adds a user-specifed key and value tag to a medical imaging resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/tag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> dict[str, Any]:
        """
        Removes tags from a medical imaging resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/untag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#untag_resource)
        """

    def update_image_set_metadata(
        self, **kwargs: Unpack[UpdateImageSetMetadataRequestTypeDef]
    ) -> UpdateImageSetMetadataResponseTypeDef:
        """
        Update image set metadata attributes.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/update_image_set_metadata.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#update_image_set_metadata)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_dicom_import_jobs"]
    ) -> ListDICOMImportJobsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_datastores"]
    ) -> ListDatastoresPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_image_set_versions"]
    ) -> ListImageSetVersionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["search_image_sets"]
    ) -> SearchImageSetsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_medical_imaging/client/#get_paginator)
        """
